<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt_BR" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>Keep contact list size</source>
        <translation>Manter tamanho da lista de contatos</translation>
    </message>
    <message>
        <source>Hide scroll bar</source>
        <translation>Esconder barra de rolagem</translation>
    </message>
    <message>
        <source>Extras</source>
        <translation>Extras</translation>
    </message>
    <message>
        <source>Simple View</source>
        <translation>Visualização simples</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opções</translation>
    </message>
    <message>
        <source>Hide window borders</source>
        <translation>Esconder bordas da janela</translation>
    </message>
</context>
<context>
    <name>SimpleView</name>
    <message>
        <source>Simple view</source>
        <translation>Visualização simples</translation>
    </message>
</context>
</TS>